@@ -955,7 +955,10 @@ def sed(graph, data):
     :param data: input training data (unique version)
     :return: corrected CPDAG
     '''
-    learned_dag = from_bnlearn(graph)
+    if type(graph) is str:
+        learned_dag = from_bnlearn(graph)
+    elif type(graph) is not dict:
+        raise Exception('The format of input graph is invalid.')
     # remove unused states
     data, _ = pre_process(data)
     varnames = data.columns.to_list()
